import { LogLevel } from "typeorm";
import { Logger, createLogger, format, transports } from "winston";
import { CoreClient } from "./client";

export default class AppLogger {
    public static InitialiseLogger(logLevel: LogLevel, outputToConsole: boolean): Logger {
        const customFormat = format.printf(({ level, message, timestamp, label }) => {
            return `${timestamp} [${label}] ${level}: ${message}`;
        });

        const logger = createLogger({
            level: logLevel,
            format: format.combine(
                format.timestamp({
                    format: 'YYYY-MM-DD HH:mm:ss'
                }),
                format.errors({ stack: true }),
                format.splat(),
                customFormat,
            ),
            defaultMeta: { service: 'bot' },
            transports: [
                new transports.File({ filename: 'error.log', level: 'error' }),
                new transports.File({ filename: 'combined.log' }),
            ],
        });

        if (outputToConsole) {
            logger.add(new transports.Console({
                format: format.combine(
                    format.colorize(),
                    format.timestamp(),
                    customFormat,
            )}));
        }

        return logger;
    }

    public static LogError(label: string, message: string) {
        CoreClient.Logger.error({ label, message });
    }

    public static LogWarn(label: string, message: string) {
        CoreClient.Logger.warn({ label, message });
    }

    public static LogInfo(label: string, message: string) {
        CoreClient.Logger.info({ label, message });
    }

    public static LogVerbose(label: string, message: string) {
        CoreClient.Logger.verbose({ label, message });
    }

    public static LogDebug(label: string, message: string) {
        CoreClient.Logger.debug({ label, message });
    }

    public static LogSilly(label: string, message: string) {
        CoreClient.Logger.silly({ label, message });
    }
}